import React, { ElementType, FunctionComponent, ReactNode } from 'react';
import { Intent } from '../../common/intent';
export declare type BannerVariant = 'lowEmphasis' | 'mediumEmphasis' | 'highEmphasis' | 'default' | 'inverted';
export declare type BannerStickyPosition = 'top' | 'bottom' | 'bottom-right';
export declare type BannerProps = {
    /**
     * Specifies the intent of the Banner (change the color of the banner icon to match intended status)
     */
    intent?: Intent;
    /**
     * Actions to be displayed inside the banner
     */
    actions?: ReactNode;
    /**
     * Class name to be added to the banner
     */
    className?: string;
    /**
     * Add a close icon in the top-right corner which will invoke the provided callback
     */
    onRequestClose?: () => void;
    /**
     * Specifies the ariaLabel to be added to the close(x) button
     */
    closeLabel?: string;
    /**
     * Specifies the variation of the banner.
     *
     * `default` and `inverted` variants are deprecated
     */
    variant?: BannerVariant;
    /**
     * Specifies if the Banner should be displayed with `position: fixed;`
     *
     * When the value is `undefined` the Banner default to being sticky if `variant` is set to `inverted`
     */
    sticky?: boolean;
    /**
     * Specifies the position of the Sticky Banner.
     */
    stickyPosition?: BannerStickyPosition;
    /**
     * Specifies if the Banner should have a border/divider at the bottom.
     */
    divider?: boolean;
    /**
     * Specify a custom icon to replace the one derived from `intent`
     *
     * @type {ElementType<{ className?: string }>}
     */
    icon?: ElementType<{
        className?: string;
    }>;
    /**
     * Specifies if the actions should always appear below the content
     */
    wrapActions?: boolean;
    /**
     * Content of the Banner
     */
    children?: ReactNode;
    /**
     * Specifies if the banner should be narrow
     */
    isNarrow?: boolean;
};
interface BannerContextInterface {
    intent: NonNullable<BannerProps['intent']>;
    variant: NonNullable<BannerProps['variant']>;
}
export declare const BannerContext: React.Context<BannerContextInterface | undefined>;
export declare const useBannerContext: () => BannerContextInterface;
export declare const Banner: FunctionComponent<BannerProps>;
export default Banner;
