import React, { ReactNode } from 'react';
import { CollapseProps } from '@kunukn/react-collapse';
export declare type AccordionHeaderProps = {
    /**
     * Add heading to the Accordion.
     */
    heading?: string;
    /**
     * Add secondary heading to the Accordion.
     */
    secondaryHeading?: ReactNode;
    /**
     * Specify the duration of the transition between open and closed.
     */
    transitionDuration?: string;
    /**
     * If set to `true` the Accordion is open.
     */
    isOpen?: boolean;
    /**
     * Disable the Accordion.
     */
    disabled?: boolean;
    /**
     * Use the Accordion without animation.
     */
    noAnimation?: boolean;
    /**
     * Hide the secondary heading when the Accordion is opened.
     */
    noSecondaryHeadingWhenOpen?: boolean;
    /**
     * Callback when toggling the accordion
     */
    onToggle?: () => void;
};
export declare const AccordionHeader: React.FunctionComponent<AccordionHeaderProps>;
export declare type AccordionProps = {
    /**
     * Add heading to the Accordion.
     */
    heading?: string;
    /**
     * Add a custom header to the Accordion.
     */
    header?: ReactNode;
    /**
     * Add secondary heading to the Accordion.
     */
    secondaryHeading?: ReactNode;
    /**
     * Specify the duration of the transition between open and closed.
     */
    transitionDuration?: string;
    /**
     * If set to `true` the Accordion is open.
     */
    isOpen?: boolean;
    /**
     * Disable the Accordion.
     */
    disabled?: boolean;
    /**
     * Callback when toggling the accordion
     */
    onToggle?: () => void;
    /**
     * Props passed on to the Collapse component
     */
    collapseProps?: CollapseProps;
    /**
     * Use the Accordion without animation.
     */
    noAnimation?: boolean;
    /**
     * The compressed variant removes the `margin-bottom` of the Accordion.
     */
    variant?: 'default' | 'compressed';
    /**
     * Specify the content padding of the Accordion.
     */
    type?: 'small' | 'medium';
    /**
     * Add a className to the Accordion.
     */
    className?: string;
    /**
     * Hide the secondary heading when the Accordion is opened.
     */
    noSecondaryHeadingWhenOpen?: boolean;
    /**
     * Hide the Divider (the grey line under the header)
     */
    hideDivider?: boolean;
    /**
     * Updates component with children prop accordingly to the @types update
     */
    children?: ReactNode;
};
export declare const Accordion: React.FunctionComponent<AccordionProps>;
export default Accordion;
