import { ComponentType, ElementType } from 'react';
export declare type RenderContainerProps<T> = {
    renderContainer: (props: T) => JSX.Element;
};
export declare type PolymorphicComponentProps = {
    /**
     * HTML tag or custom component being rendered.
     */
    as?: ElementType;
};
/**
 * Given a PolymorphicComponent and a desired RenderComponent this function will returns are new component where the
 * polymorphic prop will point to the provided `RenderComponent`.
 *
 * @example
 * import { Link } from `gatsby`;
 * import { AppBarItem, withRenderAs } from `@dfds-ui/react-components`;
 *
 * const AppBarLink = withRenderAs(AppBarItem, Link);
 *
 * const Example = () => {
 *   return <AppBarLink id="1" title="example" to="/example">Example</AppBarLink>;
 * }
 */
export declare function withRenderAs<PCProps extends PolymorphicComponentProps, RCProps>(PolymorphicComponent: ComponentType<PCProps>, RenderComponent: ComponentType<RCProps>): ({ ...props }: Omit<PCProps, keyof PolymorphicComponentProps> & RCProps) => JSX.Element;
