"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useOnClickOutside;
var _react = require("react");
/* eslint-disable react-hooks/exhaustive-deps */
/* eslint-disable react-hooks/rules-of-hooks */

const MOUSEDOWN = 'mousedown';
const TOUCHSTART = 'touchstart';
const events = [MOUSEDOWN, TOUCHSTART];
function useOnClickOutside(ref, handler) {
  const isBrowser = typeof document !== 'undefined';
  if (!isBrowser) {
    return;
  }
  const handlerRef = useLatest(handler);
  (0, _react.useEffect)(() => {
    if (!handler) {
      return;
    }
    const listener = event => {
      if (!ref.current || !handlerRef.current || ref.current.contains(event.target)) {
        return;
      }
      handlerRef.current(event);
    };
    events.forEach(event => {
      document.addEventListener(event, listener);
    });
    return () => {
      events.forEach(event => {
        document.removeEventListener(event, listener);
      });
    };
  }, [!handler]);
}
function useLatest(value) {
  const ref = (0, _react.useRef)(value);
  (0, _react.useEffect)(() => {
    ref.current = value;
  });
  return ref;
}