import React from 'react';
import { FlexBoxProps } from '../flexbox/FlexBox';
import { PolymorphicComponentProps } from '../common/polymorphic';
export declare type ListItemProps = {
    /**
     * Will render the `ListItem` with a greater `min-height` and should be used when displaying multiple lines of text.
     */
    multiline?: boolean;
    /**
     * Indicates that the `ListItem` is selected.
     */
    selected?: boolean;
    /**
     * Render the 'ListItem` without min-height.
     */
    condensed?: boolean;
    /**
     * Indicates that the `ListItem` can be focused.
     */
    tabIndex?: number;
    /**
     * Add interactive styles to the `ListItem`.
     */
    clickable?: boolean;
    /**
     * Add a divider to the `ListItem`. This will apply a border on the the `ListItem` only. If you need the indent/margin variants use
     * the `ListDivider` component instead.
     */
    divider?: boolean;
    /**
     * Invoke the provided callback when the `ListItem` is clicked.
     */
    onClick?: () => void;
    /**
     * Props controlling the flexbox.
     */
    flexBoxProps?: FlexBoxProps;
    /**
     * className to be assigned to component.
     */
    className?: string;
    children?: React.ReactNode;
} & PolymorphicComponentProps;
export declare const listItemStyles: ({ multiline, selected, clickable, condensed, flexBoxProps, divider, }: Partial<ListItemProps>) => import("@emotion/utils").SerializedStyles;
declare const ListItem: ({ children, multiline, condensed, selected, tabIndex, clickable, divider, onClick, as, flexBoxProps, ...rest }: ListItemProps) => JSX.Element;
export default ListItem;
